@@ -10,6 +10,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 # General Public License for more details.
 
+from __future__ import with_statement
+
 import contextlib
 import locale
 import os
@@ -84,6 +86,17 @@ if py3k:
 else:
     maxsize = sys.maxint
 
+@contextlib.contextmanager
+def interim(obj, **override):
+    copy = dict((key, getattr(obj, key)) for key in override)
+    for key, value in override.items():
+        setattr(obj, key, value)
+    try:
+        yield
+    finally:
+        for key, value in copy.items():
+            setattr(obj, key, value)
+
 @contextlib.contextmanager
 def raises(exc_type, string=None, regex=None):
     if string is None and regex is None:
@@ -114,8 +127,9 @@ def amended_locale(**kwargs):
             category = getattr(locale, category)
             try:
                 locale.setlocale(category, value)
-            except locale.Error, ex:
-                raise SkipTest(ex)
+            except locale.Error:
+                _, exc, _ = sys.exc_info()
+                raise SkipTest(exc)
         yield
     finally:
         locale.setlocale(locale.LC_ALL, old_locale)
@@ -136,8 +150,9 @@ def skip_unless_translation_exists(lang):
         with amended_locale(LC_ALL=lang):
             try:
                 open(__file__ + '/')
-            except EnvironmentError, ex:
-                messages[lang] = str(ex)
+            except EnvironmentError:
+                _, exc, _ = sys.exc_info()
+                messages[lang] = str(exc)
     messages = set(messages.values())
     assert 1 <= len(messages) <= 2
     if len(messages) == 1:
